==> ponyc-0.13.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/itertools-Zip5.md <==
# Zip5\[A: A, B: B, C: C, D: D, E: E\]

Zip five iterators together so that each call to next() results in the
a tuple with the next value of each of the iterators. The number of
items returned is the minimum of the number of items returned by the
iterators.

## Example Program

Print the following:

```
1 a 0.5 m 2
2 b 9.8 n 6
3 c 3.3 o 5
```

```pony
use "itertools"

actor Main
  new create(env: Env) =>
    var i1: Array[I32] ref = [as I32: 1, 2, 3]
    var i2: Array[String] ref = ["a", "b", "q", "f"]
    var i3: Array[Float] ref = [as F32: 0.5, 9.8, 3.3]
    var i4: Array[String] ref = ["m", "n", "o", "p", "q", "r"]
    var i5: Array[I32] ref = [as I32: 2, 6, 5, 3, 5]

    for (x, y, z, xx, yy) in Zip3[I32, String, F32](i1.values(), i2.values(),
      i3.values(), i4.values(), i5.values()) do
      env.out.print("".add(x.string()).add(" ").add(y).add(" ")
        .add(z).add(" ").add(xx.string()).add(" ").add(yy.string()))
    end
```


```pony
class ref Zip5[A: A, B: B, C: C, D: D, E: E] is
  Iterator[(A , B , C , D , E)] ref
```

#### Implements

* [Iterator](builtin-Iterator)\[(A , B , C , D , E)\] ref

---

## Constructors

### create

```pony
new ref create(
  i1: Iterator[A] ref,
  i2: Iterator[B] ref,
  i3: Iterator[C] ref,
  i4: Iterator[D] ref,
  i5: Iterator[E] ref)
: Zip5[A, B, C, D, E] ref^
```
#### Parameters

*   i1: [Iterator](builtin-Iterator)\[A\] ref
*   i2: [Iterator](builtin-Iterator)\[B\] ref
*   i3: [Iterator](builtin-Iterator)\[C\] ref
*   i4: [Iterator](builtin-Iterator)\[D\] ref
*   i5: [Iterator](builtin-Iterator)\[E\] ref

#### Returns

* [Zip5](itertools-Zip5)\[A, B, C, D, E\] ref^

---

## Public Functions

### has_next

```pony
fun ref has_next()
: Bool val
```

#### Returns

* [Bool](builtin-Bool) val

---

### next

```pony
fun ref next()
: (A , B , C , D , E) ?
```

#### Returns

* (A , B , C , D , E) ?

---

==> ponyc-0.18.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/itertools-Zip5.md <==
# Zip5\[A: A, B: B, C: C, D: D, E: E\]

Zip five iterators together so that each call to next() results in
a tuple with the next value of each of the iterators. The number of
items returned is the minimum of the number of items returned by the
iterators.

## Example Program

Print the following:

```
1 a 0.5 m 2
2 b 9.8 n 6
3 c 3.3 o 5
```

```pony
use "itertools"

actor Main
  new create(env: Env) =>
    var i1: Array[I32] ref = [as I32: 1; 2; 3]
    var i2: Array[String] ref = ["a"; "b"; "c"; "d"]
    var i3: Array[F32] ref = [as F32: 0.5; 9.8; 3.3]
    var i4: Array[String] ref = ["m"; "n"; "o"; "p"; "q"; "r"]
    var i5: Array[I32] ref = [as I32: 2; 6; 5; 3; 5]

    for (x, y, z, xx, yy) in Zip5[I32, String, F32, String, I32](
      i1.values(), i2.values(), i3.values(), i4.values(), i5.values())
    do
      env.out.print(""
        .add(x.string()).add(" ")
        .add(y).add(" ")
        .add(z.string()).add(" ")
        .add(xx.string()).add(" ")
        .add(yy.string()))
    end
```


```pony
class ref Zip5[A: A, B: B, C: C, D: D, E: E] is
  Iterator[(A , B , C , D , E)] ref
```

#### Implements

* [Iterator](builtin-Iterator)\[(A , B , C , D , E)\] ref

---

## Constructors

### create

```pony
new ref create(
  i1: Iterator[A] ref,
  i2: Iterator[B] ref,
  i3: Iterator[C] ref,
  i4: Iterator[D] ref,
  i5: Iterator[E] ref)
: Zip5[A, B, C, D, E] ref^
```
#### Parameters

*   i1: [Iterator](builtin-Iterator)\[A\] ref
*   i2: [Iterator](builtin-Iterator)\[B\] ref
*   i3: [Iterator](builtin-Iterator)\[C\] ref
*   i4: [Iterator](builtin-Iterator)\[D\] ref
*   i5: [Iterator](builtin-Iterator)\[E\] ref

#### Returns

* [Zip5](itertools-Zip5)\[A, B, C, D, E\] ref^

---

## Public Functions

### has_next

```pony
fun ref has_next()
: Bool val
```

#### Returns

* [Bool](builtin-Bool) val

---

### next

```pony
fun ref next()
: (A , B , C , D , E) ?
```

#### Returns

* (A , B , C , D , E) ?

---
